@@ -4,9 +4,6 @@
 
 from __future__ import absolute_import, division, print_function
 
-import sys
-import warnings
-
 from cryptography.__about__ import (
     __author__, __copyright__, __email__, __license__, __summary__, __title__,
     __uri__, __version__
@@ -17,11 +14,3 @@ __all__ = [
     "__title__", "__summary__", "__uri__", "__version__", "__author__",
     "__email__", "__license__", "__copyright__",
 ]
-
-if sys.version_info[:2] == (2, 6):
-    warnings.warn(
-        "Python 2.6 is no longer supported by the Python core team, please "
-        "upgrade your Python. The next version of cryptography will drop "
-        "support for Python 2.6",
-        DeprecationWarning
-    )
